# led-matrix-emulator
About the original PYNQ by Xilinx: https://www.pynq.io

Python library made for PYNQ emulations for TUNI Students' PYNQ-exercises
Emulator made by Riku Salminen. I don't own the library I am trying to simulate.
I can't promise full accuracy in the simulations, but I hope this is helpful for
at least testing purposes! Read documentation for more: https://riku-s.github.io/led-matrix/
